@@ -90,8 +90,8 @@ ALTER FOREIGN TABLE ft2 DROP COLUMN cx;
 -- ===================================================================
 -- tests for validator
 -- ===================================================================
--- requiressl and some other parameters are omitted because
--- valid values for them depend on configure options
+-- requiressl, krbsrvname and gsslib are omitted because they depend on
+-- configure options
 ALTER SERVER testserver1 OPTIONS (
 	use_remote_estimate 'false',
 	updatable 'true',
@@ -115,10 +115,10 @@ ALTER SERVER testserver1 OPTIONS (
 	sslcert 'value',
 	sslkey 'value',
 	sslrootcert 'value',
-	sslcrl 'value',
+	sslcrl 'value'
 	--requirepeer 'value',
-	krbsrvname 'value',
-	gsslib 'value'
+	-- krbsrvname 'value',
+	-- gsslib 'value',
 	--replication 'value'
 );
 ALTER USER MAPPING FOR public SERVER testserver1
@@ -677,11 +677,6 @@ SELECT * from loc1;
 UPDATE rem1 set f2 = 'skidoo' RETURNING f2;
 SELECT * from loc1;
 
-EXPLAIN (verbose, costs off)
-UPDATE rem1 set f1 = 10;          -- all columns should be transmitted
-UPDATE rem1 set f1 = 10;
-SELECT * from loc1;
-
 DELETE FROM rem1;
 
 -- Add a second trigger, to check that the changes are propagated correctly
@@ -935,17 +930,3 @@ DROP TYPE "Colors" CASCADE;
 IMPORT FOREIGN SCHEMA import_source LIMIT TO (t5)
   FROM SERVER loopback INTO import_dest5;  -- ERROR
 ROLLBACK;
-
--- ===================================================================
--- test connection invalidation cases
--- ===================================================================
--- This test case is for closing the connection in pgfdw_xact_callback
-BEGIN;
--- Connection xact depth becomes 1 i.e. the connection is in midst of the xact.
-SELECT 1 FROM ft1 LIMIT 1;
--- Connection is not closed at the end of the alter statement in
--- pgfdw_inval_callback. That's because the connection is in midst of this
--- xact, it is just marked as invalid.
-ALTER SERVER loopback OPTIONS (ADD use_remote_estimate 'off');
--- The invalid connection gets closed in pgfdw_xact_callback during commit.
-COMMIT;
