@@ -609,10 +609,6 @@ join_is_legal(PlannerInfo *root, RelOptInfo *rel1, RelOptInfo *rel2,
 				{
 					SpecialJoinInfo *sjinfo = (SpecialJoinInfo *) lfirst(l);
 
-					/* ignore full joins --- their ordering is predetermined */
-					if (sjinfo->jointype == JOIN_FULL)
-						continue;
-
 					if (bms_overlap(sjinfo->min_lefthand, join_plus_rhs) &&
 						!bms_is_subset(sjinfo->min_righthand, join_plus_rhs))
 					{
@@ -620,6 +616,15 @@ join_is_legal(PlannerInfo *root, RelOptInfo *rel1, RelOptInfo *rel2,
 													  sjinfo->min_righthand);
 						more = true;
 					}
+					/* full joins constrain both sides symmetrically */
+					if (sjinfo->jointype == JOIN_FULL &&
+						bms_overlap(sjinfo->min_righthand, join_plus_rhs) &&
+						!bms_is_subset(sjinfo->min_lefthand, join_plus_rhs))
+					{
+						join_plus_rhs = bms_add_members(join_plus_rhs,
+														sjinfo->min_lefthand);
+						more = true;
+					}
 				}
 			} while (more);
 			if (bms_overlap(join_plus_rhs, join_lateral_rels))
@@ -1192,8 +1197,7 @@ mark_dummy_rel(RelOptInfo *rel)
 	rel->pathlist = NIL;
 
 	/* Set up the dummy path */
-	add_path(rel, (Path *) create_append_path(rel, NIL,
-											  rel->lateral_relids));
+	add_path(rel, (Path *) create_append_path(rel, NIL, NULL));
 
 	/* Set or update cheapest_total_path and related fields */
 	set_cheapest(rel);
