@@ -144,7 +144,6 @@ typedef struct ReplicationStateCtl
 {
 	int			tranche_id;
 	LWLockTranche tranche;
-	/* Array of length max_replication_slots */
 	ReplicationState states[FLEXIBLE_ARRAY_MEMBER];
 } ReplicationStateCtl;
 
@@ -161,10 +160,6 @@ TimestampTz replorigin_session_origin_timestamp = 0;
  * max_replication_slots?
  */
 static ReplicationState *replication_states;
-
-/*
- * Actual shared memory block (replication_states[] is now part of this).
- */
 static ReplicationStateCtl *replication_states_ctl;
 
 /*
@@ -452,7 +447,7 @@ ReplicationOriginShmemSize(void)
 	/*
 	 * XXX: max_replication_slots is arguably the wrong thing to use, as here
 	 * we keep the replay state of *remote* transactions. But for now it seems
-	 * sufficient to reuse it, rather than introduce a separate GUC.
+	 * sufficient to reuse it, lest we introduce a separate guc.
 	 */
 	if (max_replication_slots == 0)
 		return size;
@@ -482,8 +477,6 @@ ReplicationOriginShmemInit(void)
 	{
 		int			i;
 
-		MemSet(replication_states_ctl, 0, ReplicationOriginShmemSize());
-
 		replication_states_ctl->tranche_id = LWLockNewTrancheId();
 		replication_states_ctl->tranche.name = "ReplicationOrigins";
 		replication_states_ctl->tranche.array_base =
@@ -491,6 +484,8 @@ ReplicationOriginShmemInit(void)
 		replication_states_ctl->tranche.array_stride =
 			sizeof(ReplicationState);
 
+		MemSet(replication_states, 0, ReplicationOriginShmemSize());
+
 		for (i = 0; i < max_replication_slots; i++)
 			LWLockInitialize(&replication_states[i].lock,
 							 replication_states_ctl->tranche_id);
@@ -1060,7 +1055,7 @@ replorigin_session_setup(RepOriginId node)
 		{
 			ereport(ERROR,
 					(errcode(ERRCODE_OBJECT_IN_USE),
-			 errmsg("replication origin with OID %d is already active for PID %d",
+			 errmsg("replication identifier %d is already active for PID %d",
 					curstate->roident, curstate->acquired_by)));
 		}
 
