@@ -635,8 +635,6 @@ SnapBuildExportSnapshot(SnapBuild *builder)
 		TransactionIdAdvance(xid);
 	}
 
-	/* adjust remaining snapshot fields as needed */
-	snap->satisfies = HeapTupleSatisfiesMVCC;
 	snap->xcnt = newxcnt;
 	snap->xip = newxip;
 
@@ -1485,8 +1483,7 @@ SnapBuildSerialize(SnapBuild *builder, XLogRecPtr lsn)
 
 	if (ret != 0 && errno != ENOENT)
 		ereport(ERROR,
-				(errcode_for_file_access(),
-				 errmsg("could not stat file \"%s\": %m", path)));
+				(errmsg("could not stat file \"%s\": %m", path)));
 
 	else if (ret == 0)
 	{
@@ -1528,7 +1525,7 @@ SnapBuildSerialize(SnapBuild *builder, XLogRecPtr lsn)
 	if (unlink(tmppath) != 0 && errno != ENOENT)
 		ereport(ERROR,
 				(errcode_for_file_access(),
-				 errmsg("could not remove file \"%s\": %m", tmppath)));
+				 errmsg("could not remove file \"%s\": %m", path)));
 
 	needed_length = sizeof(SnapBuildOnDisk) +
 		sizeof(TransactionId) * builder->committed.xcnt;
@@ -1572,8 +1569,7 @@ SnapBuildSerialize(SnapBuild *builder, XLogRecPtr lsn)
 						   S_IRUSR | S_IWUSR);
 	if (fd < 0)
 		ereport(ERROR,
-				(errcode_for_file_access(),
-				 errmsg("could not open file \"%s\": %m", tmppath)));
+				(errmsg("could not open file \"%s\": %m", path)));
 
 	errno = 0;
 	if ((write(fd, ondisk, needed_length)) != needed_length)
@@ -1699,14 +1695,12 @@ SnapBuildRestore(SnapBuild *builder, XLogRecPtr lsn)
 
 	if (ondisk.magic != SNAPBUILD_MAGIC)
 		ereport(ERROR,
-				(errcode(ERRCODE_DATA_CORRUPTED),
-				 errmsg("snapbuild state file \"%s\" has wrong magic number: %u instead of %u",
+				(errmsg("snapbuild state file \"%s\" has wrong magic number: %u instead of %u",
 						path, ondisk.magic, SNAPBUILD_MAGIC)));
 
 	if (ondisk.version != SNAPBUILD_VERSION)
 		ereport(ERROR,
-				(errcode(ERRCODE_DATA_CORRUPTED),
-				 errmsg("snapbuild state file \"%s\" has unsupported version: %u instead of %u",
+				(errmsg("snapbuild state file \"%s\" has unsupported version: %u instead of %u",
 						path, ondisk.version, SNAPBUILD_VERSION)));
 
 	INIT_CRC32C(checksum);
@@ -1771,7 +1765,7 @@ SnapBuildRestore(SnapBuild *builder, XLogRecPtr lsn)
 	/* verify checksum of what we've read */
 	if (!EQ_CRC32C(checksum, ondisk.checksum))
 		ereport(ERROR,
-				(errcode(ERRCODE_DATA_CORRUPTED),
+				(errcode_for_file_access(),
 				 errmsg("checksum mismatch for snapbuild state file \"%s\": is %u, should be %u",
 						path, checksum, ondisk.checksum)));
 
