@@ -78,7 +78,8 @@ static void add_with_check_options(Relation rel,
 								   List *permissive_policies,
 								   List *restrictive_policies,
 								   List **withCheckOptions,
-								   bool *hasSubLinks);
+								   bool *hasSubLinks,
+								   bool force_using);
 
 static bool check_role_for_policy(ArrayType *policy_roles, Oid user_id);
 
@@ -269,7 +270,8 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 							   permissive_policies,
 							   restrictive_policies,
 							   withCheckOptions,
-							   hasSubLinks);
+							   hasSubLinks,
+							   false);
 
 		/*
 		 * Get and add ALL/SELECT policies, if SELECT rights are required
@@ -292,7 +294,8 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 								   select_permissive_policies,
 								   select_restrictive_policies,
 								   withCheckOptions,
-								   hasSubLinks);
+								   hasSubLinks,
+								   true);
 		}
 
 		/*
@@ -304,6 +307,8 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 		{
 			List	   *conflict_permissive_policies;
 			List	   *conflict_restrictive_policies;
+			List	   *conflict_select_permissive_policies = NIL;
+			List	   *conflict_select_restrictive_policies = NIL;
 
 			/* Get the policies that apply to the auxiliary UPDATE */
 			get_policies_for_relation(rel, CMD_UPDATE, user_id,
@@ -321,7 +326,8 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 								   conflict_permissive_policies,
 								   conflict_restrictive_policies,
 								   withCheckOptions,
-								   hasSubLinks);
+								   hasSubLinks,
+								   true);
 
 			/*
 			 * Get and add ALL/SELECT policies, as WCO_RLS_CONFLICT_CHECK
@@ -332,9 +338,6 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 			 */
 			if (rte->requiredPerms & ACL_SELECT)
 			{
-				List	   *conflict_select_permissive_policies = NIL;
-				List	   *conflict_select_restrictive_policies = NIL;
-
 				get_policies_for_relation(rel, CMD_SELECT, user_id,
 									  &conflict_select_permissive_policies,
 									  &conflict_select_restrictive_policies);
@@ -343,7 +346,8 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 									   conflict_select_permissive_policies,
 									   conflict_select_restrictive_policies,
 									   withCheckOptions,
-									   hasSubLinks);
+									   hasSubLinks,
+									   true);
 			}
 
 			/* Enforce the WITH CHECK clauses of the UPDATE policies */
@@ -352,7 +356,23 @@ get_row_security_policies(Query *root, RangeTblEntry *rte, int rt_index,
 								   conflict_permissive_policies,
 								   conflict_restrictive_policies,
 								   withCheckOptions,
-								   hasSubLinks);
+								   hasSubLinks,
+								   false);
+
+			/*
+			 * Add ALL/SELECT policies as WCO_RLS_UPDATE_CHECK WCOs, to ensure
+			 * that the final updated row is visible when taking the UPDATE
+			 * path of an INSERT .. ON CONFLICT DO UPDATE, if SELECT rights
+			 * are required for this relation.
+			 */
+			if (rte->requiredPerms & ACL_SELECT)
+				add_with_check_options(rel, rt_index,
+									   WCO_RLS_UPDATE_CHECK,
+									   conflict_select_permissive_policies,
+									   conflict_select_restrictive_policies,
+									   withCheckOptions,
+									   hasSubLinks,
+									   true);
 		}
 	}
 
@@ -641,13 +661,14 @@ add_with_check_options(Relation rel,
 					   List *permissive_policies,
 					   List *restrictive_policies,
 					   List **withCheckOptions,
-					   bool *hasSubLinks)
+					   bool *hasSubLinks,
+					   bool force_using)
 {
 	ListCell   *item;
 	List	   *permissive_quals = NIL;
 
 #define QUAL_FOR_WCO(policy) \
-	( kind != WCO_RLS_CONFLICT_CHECK &&	\
+	( !force_using && \
 	  (policy)->with_check_qual != NULL ? \
 	  (policy)->with_check_qual : (policy)->qual )
 
