@@ -57,7 +57,7 @@ handle_help_version_opts(int argc, char *argv[],
  * Make a database connection with the given parameters.
  *
  * An interactive password prompt is automatically issued if needed and
- * allowed by cparams->prompt_password.
+ * allowed by prompt_password.
  *
  * If allow_password_reuse is true, we will try to re-use any password
  * given during previous calls to this routine.  (Callers should not pass
@@ -65,16 +65,15 @@ handle_help_version_opts(int argc, char *argv[],
  * as before, else we might create password exposure hazards.)
  */
 PGconn *
-connectDatabase(const ConnParams *cparams, const char *progname,
+connectDatabase(const char *dbname, const char *pghost,
+				const char *pgport, const char *pguser,
+				enum trivalue prompt_password, const char *progname,
 				bool echo, bool fail_ok, bool allow_password_reuse)
 {
 	PGconn	   *conn;
 	static char *password = NULL;
 	bool		new_pass;
 
-	/* Callers must supply at least dbname; other params can be NULL */
-	Assert(cparams->dbname);
-
 	if (!allow_password_reuse)
 	{
 		if (password)
@@ -82,7 +81,7 @@ connectDatabase(const ConnParams *cparams, const char *progname,
 		password = NULL;
 	}
 
-	if (cparams->prompt_password == TRI_YES && password == NULL)
+	if (password == NULL && prompt_password == TRI_YES)
 		password = simple_prompt("Password: ", 100, false);
 
 	/*
@@ -91,35 +90,23 @@ connectDatabase(const ConnParams *cparams, const char *progname,
 	 */
 	do
 	{
-		const char *keywords[8];
-		const char *values[8];
-		int			i = 0;
+		const char *keywords[7];
+		const char *values[7];
 
-		/*
-		 * If dbname is a connstring, its entries can override the other
-		 * values obtained from cparams; but in turn, override_dbname can
-		 * override the dbname component of it.
-		 */
-		keywords[i] = "host";
-		values[i++] = cparams->pghost;
-		keywords[i] = "port";
-		values[i++] = cparams->pgport;
-		keywords[i] = "user";
-		values[i++] = cparams->pguser;
-		keywords[i] = "password";
-		values[i++] = password;
-		keywords[i] = "dbname";
-		values[i++] = cparams->dbname;
-		if (cparams->override_dbname)
-		{
-			keywords[i] = "dbname";
-			values[i++] = cparams->override_dbname;
-		}
-		keywords[i] = "fallback_application_name";
-		values[i++] = progname;
-		keywords[i] = NULL;
-		values[i++] = NULL;
-		Assert(i <= lengthof(keywords));
+		keywords[0] = "host";
+		values[0] = pghost;
+		keywords[1] = "port";
+		values[1] = pgport;
+		keywords[2] = "user";
+		values[2] = pguser;
+		keywords[3] = "password";
+		values[3] = password;
+		keywords[4] = "dbname";
+		values[4] = dbname;
+		keywords[5] = "fallback_application_name";
+		values[5] = progname;
+		keywords[6] = NULL;
+		values[6] = NULL;
 
 		new_pass = false;
 		conn = PQconnectdbParams(keywords, values, true);
@@ -127,7 +114,7 @@ connectDatabase(const ConnParams *cparams, const char *progname,
 		if (!conn)
 		{
 			fprintf(stderr, _("%s: could not connect to database %s: out of memory\n"),
-					progname, cparams->dbname);
+					progname, dbname);
 			exit(1);
 		}
 
@@ -136,7 +123,7 @@ connectDatabase(const ConnParams *cparams, const char *progname,
 		 */
 		if (PQstatus(conn) == CONNECTION_BAD &&
 			PQconnectionNeedsPassword(conn) &&
-			cparams->prompt_password != TRI_NO)
+			prompt_password != TRI_NO)
 		{
 			PQfinish(conn);
 			if (password)
@@ -155,43 +142,40 @@ connectDatabase(const ConnParams *cparams, const char *progname,
 			return NULL;
 		}
 		fprintf(stderr, _("%s: could not connect to database %s: %s"),
-				progname, cparams->dbname, PQerrorMessage(conn));
+				progname, dbname, PQerrorMessage(conn));
 		exit(1);
 	}
 
-	/* Start strict; callers may override this. */
-	PQclear(executeQuery(conn, ALWAYS_SECURE_SEARCH_PATH_SQL,
-						 progname, echo));
+	if (PQserverVersion(conn) >= 70300)
+		PQclear(executeQuery(conn, ALWAYS_SECURE_SEARCH_PATH_SQL,
+							 progname, echo));
 
 	return conn;
 }
 
 /*
  * Try to connect to the appropriate maintenance database.
- *
- * This differs from connectDatabase only in that it has a rule for
- * inserting a default "dbname" if none was given (which is why cparams
- * is not const).  Note that cparams->dbname should typically come from
- * a --maintenance-db command line parameter.
  */
 PGconn *
-connectMaintenanceDatabase(ConnParams *cparams,
+connectMaintenanceDatabase(const char *maintenance_db,
+						   const char *pghost, const char *pgport,
+						   const char *pguser, enum trivalue prompt_password,
 						   const char *progname, bool echo)
 {
 	PGconn	   *conn;
 
 	/* If a maintenance database name was specified, just connect to it. */
-	if (cparams->dbname)
-		return connectDatabase(cparams, progname, echo, false, false);
+	if (maintenance_db)
+		return connectDatabase(maintenance_db, pghost, pgport, pguser,
+							   prompt_password, progname, echo, false, false);
 
 	/* Otherwise, try postgres first and then template1. */
-	cparams->dbname = "postgres";
-	conn = connectDatabase(cparams, progname, echo, true, false);
+	conn = connectDatabase("postgres", pghost, pgport, pguser, prompt_password,
+						   progname, echo, true, false);
 	if (!conn)
-	{
-		cparams->dbname = "template1";
-		conn = connectDatabase(cparams, progname, echo, false, false);
-	}
+		conn = connectDatabase("template1", pghost, pgport, pguser,
+							   prompt_password, progname, echo, false, false);
+
 	return conn;
 }
 
@@ -328,6 +312,13 @@ appendQualifiedRelation(PQExpBuffer buf, const char *spec,
 	PGresult   *res;
 	int			ntups;
 
+	/* Before 7.3, the concept of qualifying a name did not exist. */
+	if (PQserverVersion(conn) < 70300)
+	{
+		appendPQExpBufferStr(&sql, spec);
+		return;
+	}
+
 	split_table_columns_spec(spec, PQclientEncoding(conn), &table, &columns);
 
 	/*
