@@ -50,7 +50,6 @@ main(int argc, char *argv[])
 	char	   *port = NULL;
 	char	   *username = NULL;
 	enum trivalue prompt_password = TRI_DEFAULT;
-	ConnParams	cparams;
 	bool		echo = false;
 	char	   *owner = NULL;
 	char	   *tablespace = NULL;
@@ -178,19 +177,6 @@ main(int argc, char *argv[])
 			dbname = get_user_name_or_exit(progname);
 	}
 
-	/* No point in trying to use postgres db when creating postgres db. */
-	if (maintenance_db == NULL && strcmp(dbname, "postgres") == 0)
-		maintenance_db = "template1";
-
-	cparams.dbname = maintenance_db;
-	cparams.pghost = host;
-	cparams.pgport = port;
-	cparams.pguser = username;
-	cparams.prompt_password = prompt_password;
-	cparams.override_dbname = NULL;
-
-	conn = connectMaintenanceDatabase(&cparams, progname, echo);
-
 	initPQExpBuffer(&sql);
 
 	appendPQExpBuffer(&sql, "CREATE DATABASE %s",
@@ -201,25 +187,23 @@ main(int argc, char *argv[])
 	if (tablespace)
 		appendPQExpBuffer(&sql, " TABLESPACE %s", fmtId(tablespace));
 	if (encoding)
-	{
-		appendPQExpBufferStr(&sql, " ENCODING ");
-		appendStringLiteralConn(&sql, encoding, conn);
-	}
+		appendPQExpBuffer(&sql, " ENCODING '%s'", encoding);
 	if (template)
 		appendPQExpBuffer(&sql, " TEMPLATE %s", fmtId(template));
 	if (lc_collate)
-	{
-		appendPQExpBufferStr(&sql, " LC_COLLATE ");
-		appendStringLiteralConn(&sql, lc_collate, conn);
-	}
+		appendPQExpBuffer(&sql, " LC_COLLATE '%s'", lc_collate);
 	if (lc_ctype)
-	{
-		appendPQExpBufferStr(&sql, " LC_CTYPE ");
-		appendStringLiteralConn(&sql, lc_ctype, conn);
-	}
+		appendPQExpBuffer(&sql, " LC_CTYPE '%s'", lc_ctype);
 
 	appendPQExpBufferChar(&sql, ';');
 
+	/* No point in trying to use postgres db when creating postgres db. */
+	if (maintenance_db == NULL && strcmp(dbname, "postgres") == 0)
+		maintenance_db = "template1";
+
+	conn = connectMaintenanceDatabase(maintenance_db, host, port, username,
+									  prompt_password, progname, echo);
+
 	if (echo)
 		printf("%s\n", sql.data);
 	result = PQexec(conn, sql.data);
