@@ -8,10 +8,10 @@ start_test_server $tempdir;
 
 issues_sql_like(
 	[ 'vacuumdb', '--analyze-in-stages', 'postgres' ],
-qr/.*statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
-                   .*statement:\ ANALYZE.*
+qr/statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
+                   .*statement:\ ANALYZE
                    .*statement:\ SET\ default_statistics_target=10;\ RESET\ vacuum_cost_delay;
-                   .*statement:\ ANALYZE.*
+                   .*statement:\ ANALYZE
                    .*statement:\ RESET\ default_statistics_target;
                    .*statement:\ ANALYZE/sx,
 	'analyze three times');
@@ -19,16 +19,16 @@ qr/.*statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
 
 issues_sql_like(
 	[ 'vacuumdb', '--analyze-in-stages', '--all' ],
-qr/.*statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
-                   .*statement:\ ANALYZE.*
+qr/statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
+                   .*statement:\ ANALYZE
                    .*statement:\ SET\ default_statistics_target=1;\ SET\ vacuum_cost_delay=0;
-                   .*statement:\ ANALYZE.*
+                   .*statement:\ ANALYZE
                    .*statement:\ SET\ default_statistics_target=10;\ RESET\ vacuum_cost_delay;
-                   .*statement:\ ANALYZE.*
+                   .*statement:\ ANALYZE
                    .*statement:\ SET\ default_statistics_target=10;\ RESET\ vacuum_cost_delay;
-                   .*statement:\ ANALYZE.*
+                   .*statement:\ ANALYZE
                    .*statement:\ RESET\ default_statistics_target;
-                   .*statement:\ ANALYZE.*
+                   .*statement:\ ANALYZE
                    .*statement:\ RESET\ default_statistics_target;
                    .*statement:\ ANALYZE/sx,
 	'analyze more than one database in stages');
