@@ -1575,79 +1575,10 @@ DROP POLICY p1 ON dob_t1; -- should succeed
 DROP USER dob_role1;
 DROP USER dob_role2;
 
--- Bug #15708: view + table with RLS should check policies as view owner
-CREATE USER regress_rls_alice NOLOGIN;
-CREATE USER regress_rls_bob NOLOGIN;
-
-CREATE TABLE ref_tbl (a int);
-INSERT INTO ref_tbl VALUES (1);
-
-CREATE TABLE rls_tbl (a int);
-INSERT INTO rls_tbl VALUES (10);
-ALTER TABLE rls_tbl ENABLE ROW LEVEL SECURITY;
-CREATE POLICY p1 ON rls_tbl USING (EXISTS (SELECT 1 FROM ref_tbl));
-
-GRANT SELECT ON ref_tbl TO regress_rls_bob;
-GRANT SELECT ON rls_tbl TO regress_rls_bob;
-
-CREATE VIEW rls_view AS SELECT * FROM rls_tbl;
-ALTER VIEW rls_view OWNER TO regress_rls_bob;
-GRANT SELECT ON rls_view TO regress_rls_alice;
-
-SET SESSION AUTHORIZATION regress_rls_alice;
-SELECT * FROM ref_tbl; -- Permission denied
-SELECT * FROM rls_tbl; -- Permission denied
-SELECT * FROM rls_view; -- OK
-RESET SESSION AUTHORIZATION;
-
-DROP VIEW rls_view;
-DROP TABLE rls_tbl;
-DROP TABLE ref_tbl;
-
--- Leaky operator test
-CREATE TABLE rls_tbl (a int);
-INSERT INTO rls_tbl SELECT x/10 FROM generate_series(1, 100) x;
-ANALYZE rls_tbl;
-
-ALTER TABLE rls_tbl ENABLE ROW LEVEL SECURITY;
-GRANT SELECT ON rls_tbl TO regress_rls_alice;
-
-SET SESSION AUTHORIZATION regress_rls_alice;
-CREATE FUNCTION op_leak(int, int) RETURNS bool
-    AS 'BEGIN RAISE NOTICE ''op_leak => %, %'', $1, $2; RETURN $1 < $2; END'
-    LANGUAGE plpgsql;
-CREATE OPERATOR <<< (procedure = op_leak, leftarg = int, rightarg = int,
-                     restrict = scalarltsel);
-SELECT * FROM rls_tbl WHERE a <<< 1000;
-DROP OPERATOR <<< (int, int);
-DROP FUNCTION op_leak(int, int);
-RESET SESSION AUTHORIZATION;
-DROP TABLE rls_tbl;
-
--- Bug #16006: whole-row Vars in a policy don't play nice with sub-selects
-SET SESSION AUTHORIZATION regress_rls_alice;
-CREATE TABLE rls_tbl (a int, b int, c int);
-CREATE POLICY p1 ON rls_tbl USING (rls_tbl >= ROW(1,1,1));
-
-ALTER TABLE rls_tbl ENABLE ROW LEVEL SECURITY;
-ALTER TABLE rls_tbl FORCE ROW LEVEL SECURITY;
-
-INSERT INTO rls_tbl SELECT 10, 20, 30;
-EXPLAIN (VERBOSE, COSTS OFF)
-INSERT INTO rls_tbl
-  SELECT * FROM (SELECT b, c FROM rls_tbl ORDER BY a) ss;
-INSERT INTO rls_tbl
-  SELECT * FROM (SELECT b, c FROM rls_tbl ORDER BY a) ss;
-SELECT * FROM rls_tbl;
-
-DROP TABLE rls_tbl;
-RESET SESSION AUTHORIZATION;
-
 --
 -- Clean up objects
 --
-DROP USER regress_rls_alice;
-DROP USER regress_rls_bob;
+RESET SESSION AUTHORIZATION;
 
 -- Suppress NOTICE messages when doing a cascaded drop.
 SET client_min_messages TO 'warning';
